/* myMusic
 *
 * This program is distributed under the GNU General Public License, version 2.
 * A copy of this license is included with this source.
 *
 * Copyright 2004-2006, Toni Thomsson <toni@tonjac.org> 
*/

// Implementation of class Cmp3PlaylistData

#include "mp3_playlist_data.h"
#include "mp3_svc.h"
#include "mp3_config.h"

#include <time.h>
#include <sys/timeb.h>
#include <sys/types.h> 
#include <id3/tag.h>
#include <zz_file.h>
#include <winver.h>

// Construction
Cmp3PlaylistData::Cmp3PlaylistData( void )
 : CzzDataService( "listPlaylistData" )
{

}

// Destruction
Cmp3PlaylistData::~Cmp3PlaylistData()
{

}

CzzDataServiceReply* Cmp3PlaylistData::execute( void* session, CzzParameterMap* req )
{
	CzzDataService::execute( session, req );

	CzzDataServiceReply* reply = new CzzDataServiceReply();

	reply->addFieldName( MP3_FLD_LIST_ART );
	reply->addFieldName( MP3_FLD_TITLE_ROW );
	reply->addFieldName( MP3_FLD_INFO_ROW );
	reply->addFieldName( MP3_FLD_TITLE_LINK );
	reply->addFieldName( MP3_FLD_PLAY_LINK );


	long handle = 0;
	int error = 0;
	int result = 0;
	_finddata_t finfo;
	CzzString path = Cmp3Config::getM3uDir();
	CzzString subdir;
	int songs = 0;
    CzzString user = getenv( "REMOTE_USER" );

	// Find first file
    handle = _findfirst( CzzString::Format( "%s\\*%s.m3u", path.c_str(), user.c_str() ).c_str(), &finfo );

	// Read the dir
	if( (handle!= ENOENT)  && (handle != EINVAL) && (handle != -1) )
	{
		while( !error )
		{
			// We're not interested in the . and .. 
			if( (stricmp( finfo.name, "." ) != 0) && (stricmp( finfo.name, ".." ) != 0) )
			{
				// Is it a subdir?
				if( !(finfo.attrib & _A_SUBDIR) && !(finfo.attrib & _A_SYSTEM) )
				{
					subdir = path + "\\" + finfo.name;
					songs = countPlaylistSongs( subdir );
					CzzString pl = finfo.name;
					pl = pl.substr(0,strlen(finfo.name)-4);

					reply->addFieldValue( "playlist.jpg" );
					reply->addFieldValue( pl );
					reply->addFieldValue( CzzString::Format( "%d %s", songs, Cmp3Config::SONGS().c_str() ) );
					reply->addFieldValue( CzzString::Format( 
						"%s/mp3_gui.exe?svc=%d&name=%s", 
						Cmp3Config::getCGIDir().c_str(), MP3_SVC_LIST_M3U_CONTENTS, finfo.name ) );
					reply->addFieldValue( CzzString::Format( 
						"%s/mp3_playlist.exe?svc=3&name=%s", 
						Cmp3Config::getCGIDir().c_str(), finfo.name ) );
				}
			}

			// Next file
			error = _findnext( handle, &finfo );
		}
	}

	_findclose( handle );

	return reply;
}

int Cmp3PlaylistData::countPlaylistSongs( const CzzString& path )
{
	int result = 0;
	char buff[2048];
	FILE* f = fopen( path.c_str(), "r" );

	if( f != NULL )
	{
		while( fgets( buff, 2048, f ) != NULL )
		{
			if( buff[0] != '#' )
				result++;
		}

		fclose( f );
	}
	
	return result;
}

int Cmp3PlaylistData::size()
{
    return sizeof(Cmp3PlaylistData);
}