/* libzz
 *
 * This program is distributed under the GNU General Public License, version 2.
 * A copy of this license is included with this source.
 *
 * Copyright 2000-2006, Toni Thomsson <toni@tonjac.org> 
*/

/* RIS Loging Services */
           
#ifndef __rislog_h
#define __rislog_h

/* Assume C declarations for C++  */
#ifdef __cplusplus
	extern "C" {
#else
	#define bool	int	
	#define true	(int)1
	#define false	(int)0
#endif

#include "winapi.h"

	    /* data types */
typedef bool LOGRET;           
typedef unsigned int HLOG;
typedef HLOG *LPHLOG;
typedef unsigned int LOGCODE;
typedef LOGCODE *LPLOGCODE;
    
typedef struct tagLOGINFO{
	LOGCODE	logCode;
	LPSTR   lpszLogText;
} LOGINFO;
     
/* Constants */
#define MAXLOGS		 20 		  /* maximum number of simultaneous log stacks */
#define MAXMSG		 512    	  /* maximum length of error message */
#define MAXFILE      256
#define INVALID_HLOG MAXLOGS + 1  /* invalid value                  */
#define MAX_APPLEN   30            /* max length for app name */

/* log levels / severity levels  */
typedef enum tagLOGLEVEL{
	LL_DEBUG, LL_TRACE, LL_INFO, LL_WARNING, LL_ERROR, LL_FATALERROR
} LOGLEVEL;

/* log destinations */
typedef enum tagLOGDEST{
	LD_MSGBOX, LD_FILE, LD_ODS, LD_DBS, LD_STDERR, LD_EVENTLOG, LD_NULL, LD_MHS
} LOGDEST;
                  
/* function return values */
#define LOGRET_SUCCESS	true
#define LOGRET_FAIL	false

/* API */
/*#ifdef _WIN32
	#ifndef DllExport
		#define DllExport __declspec( dllexport )
	#endif			
	#define LOGAPI    LOGRET DllExport WINAPI
	#define LOGAPI_lw DllExport long WINAPI
	#define LOGAPI_lc DllExport long _cdecl
	#define LOGAPI_bc DllExport LOGRET _cdecl
#else*/
	#define LOGAPI    LOGRET
	#define LOGAPI_lw long
	#define LOGAPI_lc long 
	#define LOGAPI_bc LOGRET
//#endif


/* function prototypes */

/*------------------------------------------------------------ */

/* APIDOCSTART 
	
Function 	: logGetVersion

Description : Return version information 
	
Parameters 	:
	
NAME			TYPE	DESCRIPTION
----			----	-----------
version			OUT		Receives major version number of log module
revision		OUT		Receives minor version number of log module
build           OUT	    Receives build version number of log module

APIDOCEND */ 

/* APIDECLSTART */
LOGAPI logGetVersion( LPINT version, LPINT revision );
LOGAPI logGetVersionEx( LPINT version, LPINT revision, LPINT build );
/* APIDECLEND */

/*------------------------------------------------------------ */

/* APIDOCSTART 
	
Function 	: logInitEx

Description : Initializes new log stack and returns handle to it
	
Parameters 	:
	
NAME			TYPE	DESCRIPTION
----			----	-----------
lphLog			OUT		Receives handle to log stack
lpszApp         IN      Loginghost, application

APIDOCEND */ 

/* APIDECLSTART */
LOGAPI logInit( LPHLOG lphLog );
LOGAPI logInitEx( LPHLOG lphLog, LPSTR lpszApp );
LOGAPI logInitExEx( LPHLOG lphLog, LPSTR lpszApp, LPSTR ini );
/* APIDECLEND */

/*------------------------------------------------------------ */

/* APIDOCSTART 
	
Function 	: logFree

Description : Frees all memory used by log stack and makes HLOG
			  available for use. After calling logFree, the HLOG is 
			  invalid and may no longer be used. Obtain a new 
			  HLOG by calling logInit
	
Parameters 	:
	
NAME			TYPE	DESCRIPTION
----			----	-----------
hLog			IN		Handle to log stack (returned by previous call
						to logInit).

APIDOCEND */ 

/* APIDECLSTART */
LOGAPI logFree( HLOG hLog );
/* APIDECLEND */

/*------------------------------------------------------------ */

/* APIDOCSTART 
	
Function 	: logMsg

Description : Log message to current log destination. The message is
			  only logged if its severity is greater than or equal to
			  the current log level. Error messages are pushed onto the
			  log stack.
	
Parameters 	:
	
NAME			TYPE	DESCRIPTION
----			----	-----------
hLog			IN		Handle to log stack (returned by previous call
						to logInit).
severity		IN		Severity of message. Must be one of the LL_xxx
						constants in RSVLOG.H :            
						
						LL_DEBUG=0, LL_TRACE=1, LL_INFO=2, 
						LL_WARNING=3, LL_ERROR=4, LL_FATALERROR=5
						
logCode			IN		Error code used to identify error message. Ignored
						unless severity >= LL_ERROR. The actual value of
						logCode is not used by the function, but it is
						logged to the current destination.						
iLine			IN		Line number at which error occurred. The actual value of
						iLine is not used by the function, but it is
						logged to the current destination. TIP : Use the 
						prededfined macro __LINE__.
lpszFile		IN		Module in which error occurred. The actual value of
						lpszFile is not used by the function, but it is
						logged to the current destination. TIP : Use the 
						prededfined macro __FILE__.		
lpszLogText		IN		printf style format string that is logged to the
						current destination. 
						NB : ONLY The following simple format specifiers are 
						supported :	       
						
						i, u, d, s, ld
                        
                        Width specifiers etc are NOT supported
...				IN		Variable number of parameters (0 or more). 
						The number, types and order of these parameters must
						match the format specification in lpszLogText
                        
APIDOCEND */            

/* APIDECLSTART */
LOGAPI_bc logMsg( HLOG hLog, LOGLEVEL severity, LOGCODE logCode, int iLine, LPSTR lpszFile, LPSTR lpszLogText, ... );
/* APIDECLEND */

/*------------------------------------------------------------ */

/* APIDOCSTART 
	
Function 	: logvMsg

Description : Special form of logMsg. See logMsg
	
Parameters 	:

NAME			TYPE	DESCRIPTION
----			----	-----------
hLog			IN		See logMsg
severity		IN		 - " " -
logCode			IN       - " " -
iLine			IN		 - " " -
lpszFile		IN		 - " " -
lpszLogText		IN		 - " " -
argptr			IN		Pointer to variable number od arguments (0 or more)
						as returned by the va_start macro. Useful if your
						program calls a function with a variable number of
						arguments that in turn calls logvMsg.
                        
APIDOCEND */            

/* APIDECLSTART */
LOGAPI logvMsg( HLOG hLog, LOGLEVEL severity, LOGCODE logCode, 
				int iLine, LPSTR lpszFile, LPSTR lpszLogText, va_list argptr );
/* APIDECLEND */

/*------------------------------------------------------------ */

/* APIDOCSTART 
	
Function 	: logStr

Description : Special form of logMsg for use with programming environments
			  that don't support variable arguments lists, i.e, SQL Windows
			  and Visual Basic. See logMsg
	
Parameters 	:

NAME			TYPE	DESCRIPTION
----			----	-----------
hLog			IN		See logMsg
severity		IN		 - " " -
logCode			IN       - " " -
iLine			IN		 - " " -
lpszFile		IN		 - " " -
lpszLogText		IN		 See logMsg. The format string may NOT contain any
						 %-specifiers, as there is no argument list. You
						 must manually preformat the string before calling
						 logStr.
                        
APIDOCEND */            

/* APIDECLSTART */
LOGAPI logStr(  HLOG hLog, LOGLEVEL severity, LOGCODE logCode, 
				int iLine, LPSTR lpszFile, LPSTR lpszLogText );
/* APIDECLEND */

/*------------------------------------------------------------ */

/* APIDOCSTART 
	
Function 	: logSetLogLevel

Description : Set global log level. The new log level will be used for
			  ALL applications that subsequently call the RSVLOG DLL.
	
Parameters 	:

NAME			TYPE	DESCRIPTION
----			----	-----------
logLevel		IN		New log level. Only messages of 
						severity >= logLevel are logged to the log
						destination. Must be one of the LL_xxx
						constants in RSVLOG.H :            
						
						LL_DEBUG=0, LL_TRACE=1, LL_INFO=2, 
						LL_WARNING=3, LL_ERROR=4, LL_FATALERROR=5
APIDOCEND */            

/* APIDECLSTART */
LOGAPI logSetLogLevel( LOGLEVEL logLevel );
LOGAPI logSetLogLevelEx(HLOG hLog, LOGLEVEL logLevel );
/* APIDECLEND */

/*------------------------------------------------------------ */

/* APIDOCSTART 
	
Function 	: logSetLogDest

Description : Set global log destination. The new log destination will be 
			  used for ALL applications that subsequently call the RSVLOG DLL.
	
Parameters 	:

NAME			TYPE	DESCRIPTION
----			----	-----------
logDest		IN			New log destination. Must be one of the LD_xxx
						constants in RSVLOG.H :            
				
						LD_MSGBOX=0, LD_FILE=1, LD_ODS=2, LD_DBS=3,
						LD_STDERR=4, LD_EVENTLOG=5, LD_NULL=6
						
						Currently  LD_EVENTLOG and LD_DBS are NOT
						supported.
						 
						LD_MSGBOX : displays message in message box
						LD_FILE   : writes message to file specified by call
									to logSetLogFile. initially a default
									path and file name is used. The path is
									read from the TEMP or TMP environment
									variable. If none of these are defined,
									the path is \. The default file name is
									RSV.LOG.
						LD_ODS	  : Writes message to Debug Window using the
									Windows OutputDebugString API. This
									window is either the Output Windows in
									Microsoft Visual C++, or the window
									displayed by the DBWIN program. If no
									Debug Window is present, an error
									message will be displayed by 
									OutputDebugString.
						LD_STDERR : Works like LD_FILE, but writes output to stderr
						LD_NULL	  : Does notihing
APIDOCEND */            

/* APIDECLSTART */
LOGAPI logSetLogDest( LOGDEST logDest );
LOGAPI logSetLogDestEx(HLOG hLog, LOGDEST logDest );
/* APIDECLEND */

/*------------------------------------------------------------ */

/* APIDOCSTART 
	
Function 	: logSetLogFile

Description : Set global log file. The new log file will be used for
			  ALL applications that subsequently call the RSVLOG DLL.
			  The current log destination MUST be LD_FILE.
	
Parameters 	:

NAME			TYPE	DESCRIPTION
----			----	-----------
szLogFile		IN		Name of log file. If it does not exist, it is
						created. May contain drive and or path specification,
						in which case path must be valid. 
APIDOCEND */            

/* APIDECLSTART */
LOGAPI logSetLogFile( LPSTR szLogFile );
LOGAPI logSetLogFileEx(HLOG hLog, LPSTR szLogFile );
/* APIDECLEND */

/*------------------------------------------------------------ */

/* APIDOCSTART 
	
Function 	: logReset

Description : Resets log stack by popping all log items off stack and
			  freeing associated memory.
	
Parameters 	:
	
NAME			TYPE	DESCRIPTION
----			----	-----------
hLog			IN		Handle to log stack (returned by previous call
						to logInit).

APIDOCEND */ 

/* APIDECLSTART */
LOGAPI logReset( HLOG hLog );
/* APIDECLEND */

/*------------------------------------------------------------ */

/* APIDOCSTART 
	
Function 	: logGetLastError

Description : Pops top log item off stack and returns log code and text
			  of item.
	
Parameters 	:
	
NAME			TYPE	DESCRIPTION
----			----	-----------
hLog			IN		Handle to log stack (returned by previous call
						to logInit).
logCode			OUT		Receives log code (set by previous call to logMsg
						with severity >= LL_ERROR)
lpszLogText		OUT		Receives log text (set by previous call to logMsg
						with severity >= LL_ERROR). The memory for this
						character buffer must be allocated prior to calling
						logGetLastError and should be at least MAXMSG+1
						characters.
lpszApp         OUT     Receives loginghost, app name

APIDOCEND */ 

/* APIDECLSTART */
LOGAPI logGetLastError( HLOG hLog, LPLOGCODE logCode, LPSTR lpszLogText );
LOGAPI logGetLastErrorEx( HLOG hLog, LPLOGCODE logCode, LPSTR lpszLogText, LPSTR lpszApp );
/* APIDECLEND */

/*------------------------------------------------------------ */

/* APIDOCSTART 
	
Function 	: logMsgText

Description : Obsolete function.
	
APIDOCEND */ 

/* APIDECLSTART */
LOGAPI logMsgText( LOGCODE logCode, LPSTR *lpszLogText, LOGINFO logInfoList[] );
/* APIDECLEND */

/*------------------------------------------------------------ */

/* APIDOCSTART 
	
Function 	: logLen

Description : Calculates length of printf style format specifier and
			  accompanying variable argument list.
	
Parameters 	:
	
NAME			TYPE	DESCRIPTION
----			----	-----------
lpszFormat		IN		printf style format string that is logged to the
						current destination. 
						NB : ONLY The following simple format specifiers are 
						supported :	       
						
						i, u, d, s, ld
                        
                        Width specifiers etc are NOT supported
...				IN		Variable number of parameters (0 or more). 
						The number, types and order of these parameters must
						match the format specification in lpszLogText

Returns : 		Length of lpszFormat plus total length of expanded format 
				specifiers minus total length of format specifiers, i.e. the
				minimum size of the buffer that would be needed to 
				sprintf the string.
									
APIDOCEND */ 

/* APIDECLSTART */
LOGAPI_lc logLen( LPSTR lpszFormat, ... );
/* APIDECLEND */

/*------------------------------------------------------------ */

/* APIDOCSTART 
	
Function 	: vlogLen

Description : Special version of logLen. See logLen.
	
Parameters 	:
	
NAME			TYPE	DESCRIPTION
----			----	-----------
lpszFormat		IN		See logLen
argptr			IN		Pointer to variable number od arguments (0 or more)
						as returned by the va_start macro. Useful if your
						program calls a function with a variable number of
						arguments that in turn calls logLen.

Returns : 		See logLen.
									
APIDOCEND */ 

/* APIDECLSTART */
LOGAPI_lw vlogLen( LPSTR lpszFormat, va_list argptr );
/* APIDECLEND */

#ifndef _WIN32
     LOGAPI logStart(void);
     void logStop(void);
#endif     

     /*------------------------------------------------------------ */
#ifdef __cplusplus
}
#endif	/* __cplusplus */

#endif /* __rislog_h */


