/* libzzwin
 *
 * This program is distributed under the GNU General Public License, version 2.
 * A copy of this license is included with this source.
 *
 * Copyright 2000-2006, Toni Thomsson <toni@tonjac.org> 
*/

#ifndef zz_ctrl_panel_h
#define zz_ctrl_panel_h

#include <cpl.h>
#include <zz_export.h>

/**
	Windows controlpanel applet

	@author Toni Thomsson, toni@tonjac.org
*/
class ZZ_API CzzControlPanel
{
public:

	/**
        Create a controlpanel. Do not use directly, subclass!
	*/
    CzzControlPanel();

    virtual ~CzzControlPanel();    

    /*
		Description: 
		Anropas nr anvndaren dubbelklickar p panelen
	
		Remarks: 
		verlagringsbar, default implementationen gr inte ngot

		Returns:
		0 = OK annars fel

		See Also:
		OnGetCount()
	*/
    virtual LONG OnDblclk( HWND hwndCPl,	// IN, fnsterhandtag
							UINT uAppNum,	// IN, dialognummer (frsta dialogen 0)
							LONG lData		// IN, egendefinerat data
							); 
	
	/*
		Description: 
		Anropas nr panelen stngs
		
		Returns:
		0 = OK annars fel

		Remarks: 
		verlagringsbar, default implementationen gr inte ngot
	*/
    virtual LONG OnExit();

	/*
		Description:
		Antal dialoger som finns i kontrollpanelen

		Remarks:
		verlagringsbar, default implementationen returnerar 1
	*/
    virtual LONG OnGetCount();

	/*
		Description: 
		Anropas nr panelen laddas

		Returns:
		1 = OK annars fel

		Remarks: verlagringsbar, default implementationen gr inte ngot
	*/
    virtual LONG OnInit();

	/*
		Description: 
		Returnerar info om panelen i strukturen NEWCPLINFO

		Returns:
		0 = OK annars fel

		Remarks: 
		verlagringsbar, default implementationen returnerar fljande:
		pInfo->dwSize = sizeof(NEWCPLINFO);
		pInfo->dwFlags = 0;
		pInfo->dwHelpContext = 0;
		pInfo->lData = 0;
		pInfo->hIcon = ::LoadIcon(AfxGetResourceHandle(), MAKEINTRESOURCE(1));
		strcpy( pInfo->szName, "Applet" );
		strcpy( pInfo->szInfo, "Raw Cpl Applet" );
		strcpy( pInfo->szHelpFile, "" );

		See Also:
		Windows SDK: NEWCPLINFO
	*/
    virtual LONG OnInquire( UINT uAppNum,		// IN, dialognummer 
							NEWCPLINFO* pInfo	// UT, infostruktur
							); 

	/*
		Description: 
		Anvnds ej
	*/
    virtual LONG OnSelect( UINT uAppNum,	// IN, dialognummer 
							LONG lData		// IN,  egendefinerat data
							); 

	/*
		Description: 
		Anropas nr en dialog stngs

		Returns:
		0 = OK annars fel

		Remarks: 
		verlagringsbar, default implementationen returnerar 1
		
		See Also:
		OnExit()
	*/
    virtual LONG OnStop( UINT uAppNum,	// IN, dialognummer 
							LONG lData	// IN,  egendefinerat data
							); 

    // Description: Anropas av kontrollpanel hanteraren
	// Remarks: Anvnd ej
    static LONG APIENTRY CPlApplet( HWND hwndCPl, 
									UINT  uMsg,
                                    LONG lParam1, 
									LONG lParam2
									);

    // Description: Hack fr att n oss sjlva frn callback-funktionen
	// Remarks: Anvnd ej
    static CzzControlPanel* m_pThis;
};

#endif // zz_ctrl_panel_h

